#line 2 "lex.dynC.C"

#line 4 "lex.dynC.C"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer dynC_create_buffer
#define yy_delete_buffer dynC_delete_buffer
#define yy_flex_debug dynC_flex_debug
#define yy_init_buffer dynC_init_buffer
#define yy_flush_buffer dynC_flush_buffer
#define yy_load_buffer_state dynC_load_buffer_state
#define yy_switch_to_buffer dynC_switch_to_buffer
#define yyin dynCin
#define yyleng dynCleng
#define yylex dynClex
#define yylineno dynClineno
#define yyout dynCout
#define yyrestart dynCrestart
#define yytext dynCtext
#define yywrap dynCwrap
#define yyalloc dynCalloc
#define yyrealloc dynCrealloc
#define yyfree dynCfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE dynCrestart(dynCin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int dynCleng;

extern FILE *dynCin, *dynCout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE dynClex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-dynClineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < dynCleng; ++yyl )\
                    if ( dynCtext[yyl] == '\n' )\
                        --dynClineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --dynClineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up dynCtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up dynCtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via dynCrestart()), so that the user can continue scanning by
	 * just pointing dynCin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when dynCtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int dynCleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow dynCwrap()'s to do buffer switches
 * instead of setting up a fresh dynCin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void dynCrestart (FILE *input_file  );
void dynC_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE dynC_create_buffer (FILE *file,int size  );
void dynC_delete_buffer (YY_BUFFER_STATE b  );
void dynC_flush_buffer (YY_BUFFER_STATE b  );
void dynCpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void dynCpop_buffer_state (void );

static void dynCensure_buffer_stack (void );
static void dynC_load_buffer_state (void );
static void dynC_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER dynC_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE dynC_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE dynC_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE dynC_scan_bytes (yyconst char *bytes,int len  );

void *dynCalloc (yy_size_t  );
void *dynCrealloc (void *,yy_size_t  );
void dynCfree (void *  );

#define yy_new_buffer dynC_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        dynCensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            dynC_create_buffer(dynCin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        dynCensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            dynC_create_buffer(dynCin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define dynCwrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *dynCin = NULL, *dynCout = NULL;

typedef int yy_state_type;

extern int dynClineno;

int dynClineno = 1;

extern char *dynCtext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr dynCtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yynoreturn yy_fatal_error (yyconst char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up dynCtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	dynCleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 107
#define YY_END_OF_BUFFER 108
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[481] =
    {   0,
        0,    0,    1,    1,    0,    0,  108,  106,  103,  105,
       90,   42,   96,   89,  106,   84,   85,   94,   93,   81,
       92,   88,   95,   34,   34,   82,   76,   97,   83,   98,
      101,   33,   33,   33,   86,   87,   99,  102,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   77,  100,   78,   91,  106,  103,   90,   42,
       96,   89,  106,   84,   85,   94,   93,   81,   92,   88,
       95,   34,   34,   82,   97,   83,   98,  101,   33,   33,
       33,   86,   87,   99,  102,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,  100,

       91,    1,    3,    2,   53,   44,   43,  107,   75,   61,
       78,   80,   70,   62,    0,    0,   59,   67,   57,   68,
       34,   58,   69,    0,   40,    6,    5,   60,   41,   34,
        0,   37,    0,   34,   77,   66,   72,   74,   73,   65,
       33,    0,   33,   63,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   16,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       79,   64,   71,    0,  104,   75,   61,   78,   70,   62,
        0,  104,    0,   59,   67,   57,   68,   34,   58,   69,
        0,   40,    6,    5,   60,   41,   34,    0,   37,    0,

       34,   77,   66,   72,   74,   73,   65,   33,    0,   33,
       63,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   16,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   64,   71,    1,
        2,    2,    4,   53,   52,   45,   46,   50,   51,   47,
       49,   48,   38,   54,    0,   40,    5,   40,    0,   41,
       36,    0,   39,   35,   56,   55,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,    7,   33,   33,   33,   31,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   38,   54,    0,   40,

        5,   40,    0,   41,   36,    0,   39,   35,   56,   55,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,    7,   33,   33,   33,   31,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       45,   46,    0,   40,    0,   40,    0,   41,   39,   35,
       32,   12,    7,   33,   33,   33,   33,   15,   11,   33,
       33,   29,   33,   28,   33,   33,   33,   33,   33,   33,
       33,   33,   22,   33,   33,    0,   40,    0,   40,    0,
       41,   39,   35,   32,   12,    7,   33,   33,   33,   33,
       15,   11,   33,   33,   29,   33,   28,   33,   33,   33,

       33,   33,   33,   33,   33,   22,   33,   33,   45,    0,
       40,    0,    8,   13,   33,   33,   33,   23,   33,   33,
       24,   25,   33,   33,   33,   33,   33,   33,   10,    0,
       40,    0,    8,   13,   33,   33,   33,   23,   33,   33,
       24,   25,   33,   33,   33,   33,   33,   33,   10,   33,
       33,   33,   26,   17,   18,   19,    9,   20,   33,   33,
       33,   33,   26,   17,   18,   19,    9,   20,   33,   14,
       27,   33,   21,   14,   27,   33,   21,   30,   30,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    6,    7,    8,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   18,   18,
       18,   18,   18,   18,   18,   19,   19,   20,   21,   22,
       23,   24,   25,    1,   26,   26,   26,   26,   27,   28,
       29,   29,   29,   29,   29,   30,   29,   31,   29,   29,
       29,   29,   29,   29,   32,   29,   29,   33,   29,   29,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,

       44,   45,   46,   47,   48,   29,   29,   49,   50,   51,
       52,   53,   29,   54,   55,   56,   57,   58,   59,   33,
       60,   61,   62,   63,   64,   65,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[66] =
    {   0,
        1,    1,    2,    1,    3,    1,    1,    4,    1,    1,
        5,    1,    1,    1,    1,    1,    6,    6,    6,    1,
        7,    1,    1,    1,    1,    6,    6,    6,    8,    8,
        8,    8,    8,    1,    3,    1,    1,    8,    1,    6,
        6,    6,    6,    6,    6,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    7,    1,    7,    1
    } ;

static yyconst flex_uint16_t yy_base[494] =
    {   0,
        0,   65,  128,  129,  130,  131, 1038, 1039, 1039, 1039,
     1014, 1039,  114,  134, 1001, 1039, 1039, 1012,  130, 1039,
      131,  141,  151,  164,  151, 1039, 1039,  141, 1011,  120,
     1039,    0, 1025, 1000, 1039, 1039, 1008, 1039,  978,  133,
      143,  126,  149,  980,  101,  976,  987,  982,  145,  145,
      974,  972, 1017,  148, 1039, 1039, 1019, 1018,  187, 1017,
      199,  209,  206, 1016, 1015,  197,  212, 1014,  225,  235,
      214,  268,  323, 1013,  223,  228,  233, 1012,  380, 1006,
      981, 1009, 1008,  237, 1007,  957,  215,  214,  137,  224,
      959,  214,  955,  966,  961,  232,  215,  953,  951,  269,

      999,    0, 1039,  266,    0, 1039, 1039,  292, 1039, 1039,
     1039, 1039, 1039, 1039,  199,  281, 1039, 1039, 1039, 1039,
      285, 1039, 1039,  986,  317, 1039,    0, 1039,  429,  264,
      310,  319,    0,    0, 1039,  977, 1039, 1039, 1039,  976,
        0,  963,  967, 1039,  944,  940,  954,  942,  947,  934,
      939,  934,  931,  938,  934,  934,  932,    0,  163,  248,
      929,  105,  930,  920,  193,  932,  922,  925,  929,  928,
     1039, 1039, 1039,  972, 1039,  971,  970,  969,  968,  967,
      441,  270,  447,  966,  965,  964,  963,  356,  962,  961,
      303,  509,  960,  451,  959,  556,  603,  452,  449,  658,

      701,  958,  316,  957,  956,  955,  354,    0,  479,  927,
      953,  903,  899,  913,  901,  906,  893,  898,  893,  890,
      897,  893,  893,  877,    0,  252,  272,  860,  274,  861,
      844,  316,  852,  840,  833,  830,  824,  848,  847,    0,
      347,  349, 1039,    0, 1039,  466,  471, 1039, 1039, 1039,
     1039, 1039, 1039, 1039,  504, 1039,    0,  533,  528, 1039,
      322,  474,  562,  445, 1039, 1039,  819,  798,  802,  791,
      789,  803,  801,  793,  796,  789,  783,  797,  794,  794,
      776,    0,  789,  782,  787,    0,  769,  771,  780,  767,
      762,  762,  773,  772,  762,  769,  808,  807,  552,  806,

      527,  756,  585,  805,  582,  514,  606,  583,  804,  796,
      768,  743,  747,  736,  734,  748,  746,  737,  738,  731,
      722,  732,  728,  728,  712,    0,  724,  717,  717,    0,
      699,  701,  704,  691,  687,  687,  695,  694,  684,  687,
      478,  576,  609,  661,  631, 1039,  639,  664, 1039,  614,
        0,    0,  367,  673,  670,  675,  666,    0,    0,  671,
      658,  656,  671,    0,  659,  655,  643,  640,  643,  645,
      648,  646,    0,  644,  619,  650,  704,  723,  659,  743,
      748,  656,  722,    0,    0,  440,  598,  585,  592,  587,
        0,    0,  593,  573,  563,  577,    0,  567,  560,  554,

      542,  544,  539,  534,  530,    0,  525,  516,  647,  655,
      785,  456, 1039,    0,  513,  505,  489,    0,  490,  486,
        0,    0,  483,  484,  483,  468,  473,  475,    0,  777,
      803,  554,  507,    0,  459,  463,  449,    0,  453,  450,
        0,    0,  435,  435,  423,  407,  414,  416,    0,  397,
      345,  312,    0,    0,    0,    0,    0,    0,  286,  260,
      259,  241,    0,    0,    0,    0,    0,    0,  231,    0,
        0,  210,    0,    0,    0,  125,    0,    0,    0, 1039,
      852,  860,  868,  871,  879,  887,  895,  903,  911,  919,
      927,  166,  935

    } ;

static yyconst flex_int16_t yy_def[494] =
    {   0,
      480,  480,  481,  481,  482,  482,  480,  480,  480,  480,
      480,  480,  480,  480,  483,  480,  480,  480,  480,  480,
      480,  480,  480,  480,   24,  480,  480,  480,  480,  480,
      480,  484,  484,  484,  480,  480,  480,  480,  484,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  480,  480,  480,  480,  485,  485,  485,  485,
      485,  485,  486,  485,  485,  485,  485,  485,  485,  485,
      485,  485,  485,  485,  485,  485,  485,  485,  480,   79,
       79,  485,  485,  485,  485,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,  485,

      485,  487,  480,  488,  489,  480,  480,  490,  480,  480,
      480,  480,  480,  480,  483,  483,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  491,  480,  480,   24,
      480,  480,  492,   25,  480,  480,  480,  480,  480,  480,
      484,  483,  484,  480,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      480,  480,  480,  485,  480,  485,  485,  485,  485,  485,
      486,  483,  486,  485,  485,  485,  485,  485,  485,  485,
      485,  485,  485,  493,  485,  485,  485,  485,  485,  485,

      485,  485,  485,  485,  485,  485,  485,   79,  486,   79,
      485,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,  485,  485,  487,
      488,  488,  480,  489,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  491,  480,  480,  480,
      480,  480,  480,  492,  480,  480,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  484,  485,  485,  485,  485,

      493,  485,  485,  485,  485,  485,  485,  200,  485,  485,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  485,  485,  485,  485,  485,
      485,  485,  485,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,

       79,   79,   79,   79,   79,   79,   79,   79,  480,  480,
      480,  480,  480,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  485,
      485,  485,  485,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,  484,
      484,  484,  484,   79,   79,   79,   79,  484,   79,    0,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480

    } ;

static yyconst flex_uint16_t yy_nxt[1105] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   25,   26,
       27,   28,   29,   30,   31,   32,   32,   32,   32,   33,
       34,   32,   32,   35,    8,   36,   37,    8,   38,   32,
       39,   40,   41,   42,   43,   44,   32,   45,   46,   32,
       32,   32,   47,   48,   49,   50,   51,   52,   32,   32,
       32,   53,   54,   55,   56,   57,   58,   10,   59,   60,
       61,   62,   63,   64,   65,   66,   67,   68,   69,   70,
       71,   72,   73,   73,   74,   27,   75,   76,   77,   78,
       79,   79,   79,   79,   80,   81,   79,   79,   82,   57,

       83,   84,   57,   85,   79,   86,   87,   88,   89,   90,
       91,   79,   92,   93,   79,   79,   79,   94,   95,   96,
       97,   98,   99,   79,   79,   79,   53,  100,   55,  101,
      103,  103,  106,  106,  107,  107,  110,  111,  104,  104,
      113,  118,  139,  140,  120,  158,  135,  121,  121,  121,
      286,  159,  119,  122,  123,  124,  114,  125,  125,  125,
      287,  126,  136,  137,  108,  108,  127,  134,  134,  134,
      172,  264,  146,  128,  152,  479,  153,  112,  129,  147,
      130,  130,  130,  480,  148,  219,  149,  220,  154,  175,
      131,  163,  164,  132,  150,  132,  133,  155,  167,  175,

      165,  175,  151,  166,  168,  156,  253,  131,  182,  176,
      173,  175,  132,  174,  175,  179,  175,  281,  282,  184,
      132,  177,  178,  185,  193,  175,  115,  175,  202,  194,
      175,  180,  290,  116,  186,  175,  195,  175,  187,  175,
      183,  188,  188,  188,  203,  204,  291,  189,  190,  191,
      205,  192,  192,  192,  213,  206,  207,  216,  225,  211,
      478,  214,  112,  221,  226,  217,  215,  115,  234,  115,
      175,  175,  222,  218,  235,  477,  242,  253,  230,  231,
      223,  243,  196,  480,  197,  197,  197,  232,  115,  283,
      233,  238,  476,  261,  198,  261,  480,  199,  284,  199,

      200,  121,  121,  121,  116,  175,  325,  326,  246,  246,
      247,  198,  261,  327,  475,  474,  199,  298,  175,  330,
      261,  262,  328,  262,  199,  175,  263,  263,  263,  331,
      473,  239,  248,  125,  125,  125,  249,  196,  309,  201,
      201,  201,  250,  255,  256,  251,  256,  252,  132,  198,
      132,  261,  199,  261,  199,  334,  175,  480,  175,  242,
      255,  256,  480,  472,  243,  256,  198,  132,  412,  335,
      261,  199,  188,  188,  188,  132,  310,  413,  261,  199,
      174,  174,  175,  174,  174,  174,  174,  174,  174,  174,
      174,  174,  174,  174,  174,  174,  208,  208,  208,  174,

      471,  174,  174,  174,  174,  208,  208,  208,  208,  208,
      208,  208,  208,  174,  174,  174,  174,  208,  174,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  432,  174,  182,  174,  258,  258,  258,  297,  175,
      433,  175,  470,  175,  175,  259,  260,  412,  260,  469,
      468,  115,  467,  306,  466,  306,  413,  115,  307,  307,
      307,  257,  259,  260,  350,  183,  350,  260,  199,  465,
      199,  182,  341,  341,  342,  464,  174,  342,  342,  342,
      263,  263,  263,  350,  409,  409,  342,  199,  463,  115,

      462,  350,  115,  461,  115,  199,  326,  460,  115,  175,
      115,  175,  257,  183,  257,  343,  175,  343,  459,  458,
      344,  344,  344,  457,  456,  192,  192,  192,  455,  175,
      307,  307,  307,  454,  453,  299,  300,  452,  300,  347,
      115,  347,  115,  451,  348,  348,  348,  257,  282,  258,
      258,  258,  299,  300,  175,  432,  175,  300,  175,  345,
      346,  450,  346,  376,  433,  376,  449,  448,  377,  377,
      377,  447,  302,  302,  302,  446,  345,  346,  263,  263,
      263,  346,  303,  304,  175,  304,  445,  175,  257,  349,
      257,  349,  342,  342,  342,  444,  380,  326,  380,  303,

      304,  381,  381,  381,  304,  175,  349,  443,  175,  442,
      349,  305,  383,  305,  383,  441,  440,  196,  439,  197,
      197,  197,  307,  307,  307,  344,  344,  344,  326,  198,
      305,  383,  305,  382,  305,  382,  438,  437,  305,  383,
      436,  435,  410,  350,  410,  350,  198,  411,  411,  411,
      382,  305,  175,  434,  382,  348,  348,  348,  175,  305,
      175,  175,  350,  342,  342,  342,  377,  377,  377,  429,
      350,  411,  411,  411,  308,  308,  308,  344,  344,  344,
      348,  348,  348,  308,  308,  308,  428,  427,  256,  426,
      256,  260,  425,  260,  424,  282,  423,  308,  308,  308,

      308,  308,  308,  175,  422,  256,  175,  421,  260,  256,
      420,  419,  260,  282,  418,  196,  417,  201,  201,  201,
      377,  377,  377,  416,  175,  175,  415,  198,  414,  326,
      199,  300,  199,  300,  430,  408,  430,  407,  406,  431,
      431,  431,  405,  404,  198,  175,  403,  402,  300,  199,
      175,  383,  300,  383,  401,  400,  399,  199,  175,  381,
      381,  381,  326,  398,  381,  381,  381,  397,  396,  395,
      383,  394,  302,  302,  302,  304,  393,  304,  383,  175,
      392,  391,  378,  379,  390,  379,  389,  388,  387,  386,
      385,  326,  304,  431,  431,  431,  304,  384,  175,  378,

      379,  411,  411,  411,  379,  175,  175,  175,  175,  175,
      175,  282,  346,  375,  346,  374,  373,  372,  371,  431,
      431,  431,  370,  369,  368,  367,  366,  282,  365,  346,
      379,  364,  379,  346,  363,  362,  361,  360,  359,  358,
      357,  356,  355,  354,  353,  352,  282,  379,  351,  175,
      175,  379,  102,  102,  102,  102,  102,  102,  102,  102,
      105,  105,  105,  105,  105,  105,  105,  105,  115,  115,
      115,  340,  115,  115,  115,  115,  141,  339,  141,  174,
      174,  174,  174,  174,  174,  338,  174,  181,  181,  181,
      181,  181,  181,  181,  181,  240,  337,  240,  240,  336,

      240,  240,  240,  241,  333,  241,  241,  241,  241,  241,
      241,  244,  332,  329,  244,  244,  244,  244,  244,  245,
      245,  245,  245,  245,  245,  245,  245,  257,  324,  257,
      257,  257,  257,  257,  257,  301,  301,  301,  301,  301,
      301,  301,  301,  323,  322,  321,  320,  319,  318,  317,
      316,  315,  314,  313,  312,  175,  311,  175,  175,  175,
      175,  175,  175,  175,  175,  175,  175,  175,  175,  175,
      175,  175,  175,  175,  175,  296,  295,  294,  293,  292,
      289,  288,  285,  280,  279,  278,  277,  276,  275,  274,
      273,  272,  271,  270,  269,  268,  267,  116,  266,  265,

      254,  175,  237,  236,  229,  228,  227,  224,  212,  175,
      175,  175,  210,  209,  175,  175,  175,  175,  175,  175,
      175,  175,  171,  170,  169,  162,  161,  160,  157,  145,
      144,  143,  142,  138,  117,  116,  109,  480,    7,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,

      480,  480,  480,  480
    } ;

static yyconst flex_int16_t yy_chk[1105] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,

        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        3,    4,    5,    6,    5,    6,   13,   13,    3,    4,
       14,   19,   30,   30,   21,   45,   28,   21,   21,   21,
      162,   45,   19,   21,   21,   22,   14,   22,   22,   22,
      162,   23,   28,   28,    5,    6,   23,   25,   25,   25,
       54,  492,   40,   23,   42,  476,   42,   13,   24,   40,
       24,   24,   24,   25,   40,   89,   41,   89,   43,   59,
       24,   49,   49,   24,   41,   24,   24,   43,   50,   66,

       49,   61,   41,   49,   50,   43,  115,   24,   63,   59,
       54,   62,   24,   63,   67,   62,   71,  159,  159,   66,
       24,   61,   61,   67,   71,   75,   63,   69,   75,   71,
       76,   62,  165,  115,   67,   77,   71,   70,   69,   84,
       63,   69,   69,   69,   75,   75,  165,   69,   69,   70,
       76,   70,   70,   70,   87,   77,   77,   88,   92,   84,
      472,   87,   61,   90,   92,   88,   87,   63,   97,   63,
       72,  100,   90,   88,   97,  469,  104,  182,   96,   96,
       90,  104,   72,  116,   72,   72,   72,   96,  116,  160,
       96,  100,  462,  130,   72,  130,  130,   72,  160,   72,

       72,  121,  121,  121,  182,  191,  226,  226,  108,  108,
      108,   72,  130,  227,  461,  460,   72,  191,  203,  229,
      130,  131,  227,  131,   72,   73,  131,  131,  131,  229,
      459,  100,  108,  125,  125,  125,  108,   73,  203,   73,
       73,   73,  108,  125,  125,  108,  125,  108,  132,   73,
      132,  261,   73,  261,   73,  232,  207,  241,  188,  242,
      125,  125,  241,  452,  242,  125,   73,  132,  353,  232,
      261,   73,  188,  188,  188,  132,  207,  353,  261,   73,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,

      451,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,  386,   79,  181,   79,  129,  129,  129,  181,  183,
      386,  199,  450,  194,  198,  129,  129,  412,  129,  448,
      447,  181,  446,  198,  445,  198,  412,  183,  198,  198,
      198,  194,  129,  129,  264,  181,  264,  129,  199,  444,
      199,  209,  246,  246,  246,  443,  209,  247,  247,  247,
      262,  262,  262,  264,  341,  341,  341,  199,  440,  209,

      439,  264,  181,  437,  181,  199,  436,  435,  183,  433,
      183,  192,  194,  209,  194,  255,  306,  255,  428,  427,
      255,  255,  255,  426,  425,  192,  192,  192,  424,  301,
      306,  306,  306,  423,  420,  192,  192,  419,  192,  259,
      209,  259,  209,  417,  259,  259,  259,  301,  416,  258,
      258,  258,  192,  192,  299,  432,  432,  192,  196,  258,
      258,  415,  258,  299,  432,  299,  408,  407,  299,  299,
      299,  405,  196,  196,  196,  404,  258,  258,  263,  263,
      263,  258,  196,  196,  305,  196,  403,  303,  301,  263,
      301,  263,  342,  342,  342,  402,  303,  401,  303,  196,

      196,  303,  303,  303,  196,  197,  263,  400,  307,  399,
      263,  305,  308,  305,  308,  398,  396,  197,  395,  197,
      197,  197,  307,  307,  307,  343,  343,  343,  394,  197,
      305,  308,  197,  307,  197,  307,  393,  390,  305,  308,
      389,  388,  345,  350,  345,  350,  197,  345,  345,  345,
      307,  197,  376,  387,  307,  347,  347,  347,  382,  197,
      200,  379,  350,  409,  409,  409,  376,  376,  376,  375,
      350,  410,  410,  410,  200,  200,  200,  344,  344,  344,
      348,  348,  348,  200,  200,  200,  374,  372,  344,  371,
      344,  348,  370,  348,  369,  368,  367,  200,  200,  200,

      200,  200,  200,  201,  366,  344,  377,  365,  348,  344,
      363,  362,  348,  361,  360,  201,  357,  201,  201,  201,
      377,  377,  377,  356,  383,  378,  355,  201,  354,  340,
      201,  377,  201,  377,  378,  339,  378,  338,  337,  378,
      378,  378,  336,  335,  201,  380,  334,  333,  377,  201,
      381,  383,  377,  383,  332,  331,  329,  201,  302,  380,
      380,  380,  328,  327,  381,  381,  381,  325,  324,  323,
      383,  322,  302,  302,  302,  381,  321,  381,  383,  430,
      320,  319,  302,  302,  318,  302,  317,  316,  315,  314,
      313,  312,  381,  430,  430,  430,  381,  311,  310,  302,

      302,  411,  411,  411,  302,  431,  309,  304,  300,  298,
      297,  296,  411,  295,  411,  294,  293,  292,  291,  431,
      431,  431,  290,  289,  288,  287,  285,  284,  283,  411,
      431,  281,  431,  411,  280,  279,  278,  277,  276,  275,
      274,  273,  272,  271,  270,  269,  268,  431,  267,  239,
      238,  431,  481,  481,  481,  481,  481,  481,  481,  481,
      482,  482,  482,  482,  482,  482,  482,  482,  483,  483,
      483,  237,  483,  483,  483,  483,  484,  236,  484,  485,
      485,  485,  485,  485,  485,  235,  485,  486,  486,  486,
      486,  486,  486,  486,  486,  487,  234,  487,  487,  233,

      487,  487,  487,  488,  231,  488,  488,  488,  488,  488,
      488,  489,  230,  228,  489,  489,  489,  489,  489,  490,
      490,  490,  490,  490,  490,  490,  490,  491,  224,  491,
      491,  491,  491,  491,  491,  493,  493,  493,  493,  493,
      493,  493,  493,  223,  222,  221,  220,  219,  218,  217,
      216,  215,  214,  213,  212,  211,  210,  206,  205,  204,
      202,  195,  193,  190,  189,  187,  186,  185,  184,  180,
      179,  178,  177,  176,  174,  170,  169,  168,  167,  166,
      164,  163,  161,  157,  156,  155,  154,  153,  152,  151,
      150,  149,  148,  147,  146,  145,  143,  142,  140,  136,

      124,  101,   99,   98,   95,   94,   93,   91,   86,   85,
       83,   82,   81,   80,   78,   74,   68,   65,   64,   60,
       58,   57,   53,   52,   51,   48,   47,   46,   44,   39,
       37,   34,   33,   29,   18,   15,   11,    7,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,
      480,  480,  480,  480,  480,  480,  480,  480,  480,  480,

      480,  480,  480,  480
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[108] =
    {   0,
0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
    0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 1, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int dynC_flex_debug;
int dynC_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *dynCtext;
#line 1 "C.l"


#line 17 "C.l"

#include <stdio.h>
#include <string>
#include "BPatch_snippet.h"
#include <vector>
#include "dynC.tab.h"
#include "snippetGen.h"

int line_num = 1;

extern "C" {
  void set_lex_input(char *);
}

std::string lineStr;
static char *input_str = NULL;  


int yycolumn = 0;

extern bool fatalError;



#define YY_USER_ACTION dynClloc.first_line = dynClloc.last_line = line_num;\
        dynClloc.first_column = yycolumn; dynClloc.last_column = yycolumn+dynCleng-1;\
        yycolumn += dynCleng;\
        lineStr = dynCtext;

#define input() (*input_str++)
//#define yyinput() (*input_str++)
#define yylval dynClval

std::string c_string_buf = "";

const bool lexVerbose = false; // set to true for debug mode

//"$"{L}({L}|{D})* { yylval.sval = &dynCtext[1]; return(DYNINST_CALL); }

#line 951 "lex.dynC.C"

#define INITIAL 0
#define comment 1
#define stringmode 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int dynClex_destroy (void );

int dynCget_debug (void );

void dynCset_debug (int debug_flag  );

YY_EXTRA_TYPE dynCget_extra (void );

void dynCset_extra (YY_EXTRA_TYPE user_defined  );

FILE *dynCget_in (void );

void dynCset_in  (FILE * _in_str  );

FILE *dynCget_out (void );

void dynCset_out  (FILE * _out_str  );

			int dynCget_leng (void );

char *dynCget_text (void );

int dynCget_lineno (void );

void dynCset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int dynCwrap (void );
#else
extern int dynCwrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT

#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( dynCtext, (size_t) dynCleng, 1, dynCout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( dynCin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( dynCin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, dynCin))==0 && ferror(dynCin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(dynCin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int dynClex (void);

#define YY_DECL int dynClex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after dynCtext and dynCleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( dynCleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(dynCtext[dynCleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! dynCin )
			dynCin = stdin;

		if ( ! dynCout )
			dynCout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			dynCensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				dynC_create_buffer(dynCin,YY_BUF_SIZE );
		}

		dynC_load_buffer_state( );
		}

	{
#line 58 "C.l"


#line 1175 "lex.dynC.C"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of dynCtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 481 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1039 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < dynCleng; ++yyl )
				if ( dynCtext[yyl] == '\n' )
					   
    dynClineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 62 "C.l"
/* eat anything that's not a '*' */ 
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 63 "C.l"
/* eat up '*'s not followed by '/'s */                           
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 64 "C.l"
++line_num;                                                      
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 65 "C.l"
BEGIN(INITIAL);       
	YY_BREAK
case YY_STATE_EOF(comment):
#line 66 "C.l"
{yylval.context = "Syntax Error: Unterminated block comment"; return(D_ERROR);}
	YY_BREAK

case 5:
YY_RULE_SETUP
#line 69 "C.l"
{ if(lexVerbose)printf("Inline Comment\n") /* inline comment */;}                            
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 70 "C.l"
{ BEGIN(comment); }                                                  
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 72 "C.l"
{ yylval.sval = strdup(dynCtext); return TYPE;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 73 "C.l"
{yylval.sval = strdup("char *"); return TYPE; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 75 "C.l"
{return STRUCT; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 76 "C.l"
{return UNION; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 77 "C.l"
{return ENUM; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 79 "C.l"
{ return(CASE); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 80 "C.l"
{ return(D_CONST); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 81 "C.l"
{ return(DEFAULT); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 82 "C.l"
{ return(ELSE); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 83 "C.l"
{ return(IF); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 84 "C.l"
{ return(RETURN); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 85 "C.l"
{ return(SIZEOF); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 86 "C.l"
{ return(STATIC); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 87 "C.l"
{ return(SWITCH); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 88 "C.l"
{ return(TYPEDEF); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 89 "C.l"
{ return(D_TRUE); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 90 "C.l"
{ return(D_FALSE); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 92 "C.l"
{ return(LOCAL); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 93 "C.l"
{ return(PARAM); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 94 "C.l"
{ return(GLOBAL); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 95 "C.l"
{ return(DYNINST); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 96 "C.l"
{ return(INST); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 97 "C.l"
{ return(FUNC); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 98 "C.l"
{ return(FUNC); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 99 "C.l"
{ return(REGISTER); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 100 "C.l"
{return (NILL); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 102 "C.l"
{yylval.sval = strdup(dynCtext); if(lexVerbose) printf("ID: %s\n", dynCtext); return(IDENTIFIER); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 106 "C.l"
{ yylval.ival = atoi(dynCtext); return NUMBER;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 108 "C.l"
{ return(CONSTANT); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 109 "C.l"
{ return(CONSTANT); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 110 "C.l"
{ return(CONSTANT); }
	YY_BREAK
case 38:
/* rule 38 can match eol */
YY_RULE_SETUP
#line 111 "C.l"
{ return(CONSTANT); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 113 "C.l"
{ return(CONSTANT); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 114 "C.l"
{ return(CONSTANT); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 115 "C.l"
{ return(CONSTANT); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 117 "C.l"
{if(lexVerbose)printf("String Mode!\n"); c_string_buf = ""; BEGIN(stringmode);} 
	YY_BREAK

case 43:
YY_RULE_SETUP
#line 121 "C.l"
{ /* saw closing quote - all done */
                  // this string handling code was taken from the flex manual
                  if(lexVerbose)printf("string done\n");
                  BEGIN(INITIAL);                                                    
                  yylval.sval = strdup(c_string_buf.c_str());
                  return STRING;                                                     
                }
	YY_BREAK
case 44:
/* rule 44 can match eol */
YY_RULE_SETUP
#line 129 "C.l"
{ /* error - unterminated strin constant */
                  yylval.context = "Unterminated string constant";
                  yycolumn = 1;
                  //yylval.line_number = line_num;                                                     line_num++;
                  return D_ERROR;
                }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 136 "C.l"
{ /* octal escape sequence */
                  int result;                                                        
                  (void) sscanf( dynCtext + 1, "%o", &result );                        
                  if ( result > 0xff ){
                      /* error, constant is out-of-bounds */
                      yylval.context = "constant out of bounds";                
                     // yylval.line_number = line_num;                            
                      return D_ERROR;
                  }
                  c_string_buf += result;                                            
  
                }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 149 "C.l"
{ /* generate error - bad escape sequence */
                  yylval.context = "bad escape sequence";                       
                 // yylval.line_number = line_num;                                
                  return D_ERROR;
                }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 154 "C.l"
c_string_buf += '\n';                                                
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 155 "C.l"
c_string_buf += '\t';                                                
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 156 "C.l"
c_string_buf += '\r';                                                
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 157 "C.l"
c_string_buf += '\b';                                             
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 158 "C.l"
c_string_buf += '\f';                                                
	YY_BREAK
case 52:
/* rule 52 can match eol */
YY_RULE_SETUP
#line 160 "C.l"
c_string_buf += dynCtext[1];
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 161 "C.l"
{
                  char *yptr = dynCtext;
                  while ( *yptr ) { c_string_buf += *yptr++; }
                }
	YY_BREAK

case 54:
YY_RULE_SETUP
#line 168 "C.l"
{ return(ELLIPSIS); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 169 "C.l"
{ return(RIGHT_ASSIGN); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 170 "C.l"
{ return(LEFT_ASSIGN); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 171 "C.l"
{ return(ADD_ASSIGN); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 172 "C.l"
{ return(SUB_ASSIGN); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 173 "C.l"
{ return(MUL_ASSIGN); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 174 "C.l"
{ return(DIV_ASSIGN); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 175 "C.l"
{ return(MOD_ASSIGN); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 176 "C.l"
{ return(AND_ASSIGN); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 177 "C.l"
{ return(XOR_ASSIGN); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 178 "C.l"
{ return(OR_ASSIGN); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 179 "C.l"
{ return(RIGHT_OP); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 180 "C.l"
{ return(LEFT_OP); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 181 "C.l"
{ return(INC_OP); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 182 "C.l"
{ return(DEC_OP); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 183 "C.l"
{ return(PTR_OP); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 184 "C.l"
{ return(AND); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 185 "C.l"
{ return(OR); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 186 "C.l"
{ return(LESS_EQ); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 187 "C.l"
{ return(GREATER_EQ); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 188 "C.l"
{ return(EQ); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 189 "C.l"
{ return(NOT_EQ); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 190 "C.l"
{ return(SEMI); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 191 "C.l"
{ return('{'); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 192 "C.l"
{ return('}'); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 193 "C.l"
{ return(NOPEN); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 194 "C.l"
{ return(NCLOSE); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 195 "C.l"
{ return(COMMA); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 196 "C.l"
{ return(COLON); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 197 "C.l"
{ return(ASSIGN); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 198 "C.l"
{ if(lexVerbose)printf("(\n"); return('('); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 199 "C.l"
{ if(lexVerbose)printf(")\n"); return(')'); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 200 "C.l"
{ return('['); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 201 "C.l"
{ return(']'); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 202 "C.l"
{ return(DOT); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 203 "C.l"
{ return('&'); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 204 "C.l"
{ return('!'); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 205 "C.l"
{ return('~'); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 206 "C.l"
{ return('-'); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 207 "C.l"
{ return('+'); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 208 "C.l"
{ return('*'); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 209 "C.l"
{ return('/'); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 210 "C.l"
{ return('%'); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 211 "C.l"
{ return('<'); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 212 "C.l"
{ return('>'); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 213 "C.l"
{ return('^'); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 214 "C.l"
{ return('|'); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 215 "C.l"
{ return('?'); }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 216 "C.l"
{ if(lexVerbose)printf("Backtick\n"); return(BACKTICK); }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 217 "C.l"
{ }
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
#line 219 "C.l"
{if(strstr(dynCtext, "//") != NULL){++line_num;}else{if(strncmp(dynCtext,"/*", 2) == 0){BEGIN(comment);++line_num;}else{if(lexVerbose)printf("No Semi!\n"); fatalError = true; dynClloc.first_column = yycolumn; yylval.context = "syntax error: missing ';'!"; yyless(dynCleng - 1); return(D_ERROR);}}}
	YY_BREAK
case 105:
/* rule 105 can match eol */
YY_RULE_SETUP
#line 221 "C.l"
{if(lexVerbose)printf("New Line!\n"); line_num++; yycolumn = 0; lineStr = "";}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 223 "C.l"
{ if(lexVerbose) printf("Unrecognized [%s]\n", dynCtext); /* ignore bad characters */ }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 227 "C.l"
ECHO;
	YY_BREAK
#line 1820 "lex.dynC.C"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(stringmode):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed dynCin at a new source and called
			 * dynClex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = dynCin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( dynCwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * dynCtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of dynClex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	yy_size_t number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					dynCrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			dynCrestart(dynCin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((int) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) dynCrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 481 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 481 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 480);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					dynCrestart(dynCin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( dynCwrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve dynCtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
	if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
		   
    dynClineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void dynCrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        dynCensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            dynC_create_buffer(dynCin,YY_BUF_SIZE );
	}

	dynC_init_buffer(YY_CURRENT_BUFFER,input_file );
	dynC_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void dynC_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		dynCpop_buffer_state();
	 *		dynCpush_buffer_state(new_buffer);
     */
	dynCensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	dynC_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (dynCwrap()) processing, but the only time this flag
	 * is looked at is after dynCwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void dynC_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	dynCin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE dynC_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) dynCalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in dynC_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) dynCalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in dynC_create_buffer()" );

	b->yy_is_our_buffer = 1;

	dynC_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with dynC_create_buffer()
 * 
 */
    void dynC_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		dynCfree((void *) b->yy_ch_buf  );

	dynCfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a dynCrestart() or at EOF.
 */
    static void dynC_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	dynC_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then dynC_init_buffer was _probably_
     * called from dynCrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void dynC_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		dynC_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void dynCpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	dynCensure_buffer_stack();

	/* This block is copied from dynC_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from dynC_switch_to_buffer. */
	dynC_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void dynCpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	dynC_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		dynC_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void dynCensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)dynCalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in dynCensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)dynCrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in dynCensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE dynC_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) dynCalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in dynC_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	dynC_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to dynClex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       dynC_scan_bytes() instead.
 */
YY_BUFFER_STATE dynC_scan_string (yyconst char * yystr )
{
    
	return dynC_scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to dynClex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE dynC_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) _yybytes_len + 2;
	buf = (char *) dynCalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in dynC_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = dynC_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in dynC_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up dynCtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		dynCtext[dynCleng] = (yy_hold_char); \
		(yy_c_buf_p) = dynCtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		dynCleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int dynCget_lineno  (void)
{
        
    return dynClineno;
}

/** Get the input stream.
 * 
 */
FILE *dynCget_in  (void)
{
        return dynCin;
}

/** Get the output stream.
 * 
 */
FILE *dynCget_out  (void)
{
        return dynCout;
}

/** Get the length of the current token.
 * 
 */
int dynCget_leng  (void)
{
        return dynCleng;
}

/** Get the current token.
 * 
 */

char *dynCget_text  (void)
{
        return dynCtext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void dynCset_lineno (int  _line_number )
{
    
    dynClineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see dynC_switch_to_buffer
 */
void dynCset_in (FILE *  _in_str )
{
        dynCin = _in_str ;
}

void dynCset_out (FILE *  _out_str )
{
        dynCout = _out_str ;
}

int dynCget_debug  (void)
{
        return dynC_flex_debug;
}

void dynCset_debug (int  _bdebug )
{
        dynC_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from dynClex_destroy(), so don't allocate here.
     */

    /* We do not touch dynClineno unless the option is enabled. */
    dynClineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    dynCin = stdin;
    dynCout = stdout;
#else
    dynCin = NULL;
    dynCout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * dynClex_init()
     */
    return 0;
}

/* dynClex_destroy is for both reentrant and non-reentrant scanners. */
int dynClex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		dynC_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		dynCpop_buffer_state();
	}

	/* Destroy the stack itself. */
	dynCfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * dynClex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *dynCalloc (yy_size_t  size )
{
			return malloc(size);
}

void *dynCrealloc  (void * ptr, yy_size_t  size )
{

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void dynCfree (void * ptr )
{
			free( (char *) ptr );	/* see dynCrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 227 "C.l"



void set_lex_input(char *str)
{
   static bool firstCall = true;
   YY_BUFFER_STATE bp;
   
   //db removed firstcall check
   if(!firstCall) dynC_flush_buffer(YY_CURRENT_BUFFER);
   yycolumn = 0;
   line_num = 1;
   
   input_str = str;
   bp = dynC_scan_string(str);
   (void)bp; // unused warning...
   firstCall = false;
}


